@@ -5,7 +5,8 @@
 #' @param end_date series final date. Accepts ISO character formated date and \code{Date}.
 #' @param last last items of the series
 #' @param name series name to be used in the returning object
-#' @param as the returning type: \code{tibble, xts, data.frame}
+#' @param as the returning type: data objects (\code{tibble, xts, data.frame, ts}) or \code{text} for raw JSON
+#' @param ts_options options to be passed to \code{ts} function (when \code{as = 'ts'} provided)
 #'
 #' \code{code} argument can be obtained in the SGS system site. In this site searches can be executed in
 #' order to find out the desired series and use the series code in the \code{code} argument.
@@ -23,7 +24,7 @@
 #'
 #' @return
 #' \code{tibble} is the default returning class, but the argument \code{as} can be set
-#' to \code{xts}, \code{data.frame}, or \code{text} to return these other types.
+#' to \code{xts}, \code{data.frame}, \code{ts}, or \code{text} to return these other types.
 #' \code{text} returns the JSON data provided by the remote API.
 #'
 #' @examples
@@ -38,14 +39,15 @@
 #' @export
 get_series <- function(code, start_date = NULL, end_date = NULL, last = 0,
                        name = NULL,
-                       as = c('tibble', 'xts', 'data.frame', 'text')) {
+                       as = c('tibble', 'xts', 'ts', 'data.frame', 'text'), ts_options = NULL) {
   as <- match.arg(as)
   url <- series_url(code, start_date, end_date, last)
-  res <- httr::GET(url)
+  res <- http_getter(url)
   if (res$status_code != 200) {
     stop("BCB API Request error, status code = ", res$status_code)
   }
-  json_ <- httr::content(res, as = "text")
+  # json_ <- httr::content(res, as = "text")
+  json_ <- http_gettext(res)
 
   if (as == 'text')
     return(json_)
@@ -60,15 +62,37 @@ get_series <- function(code, start_date = NULL, end_date = NULL, last = 0,
 
   name_ <- if (is.null(name)) code else name
 
-  if (as == 'tibble') {
-    df_ <- tibble::as_tibble(df_)
-    names(df_) <- c('date', name_)
-  } else if (as == 'data.frame') {
-    names(df_) <- c('date', name_)
-  } else if (as == 'xts') {
-    df_ <- xts::xts(df_$value, df_$date)
-    names(df_) <- name_
-  }
+  switch (as,
+    'tibble' = {
+      df_ <- tibble::as_tibble(df_)
+      names(df_) <- c('date', name_)
+      df_
+    },
+    'data.frame' = {
+      names(df_) <- c('date', name_)
+      df_
+    },
+    'xts' = {
+      df_ <- xts::xts(df_$value, df_$date)
+      names(df_) <- name_
+      df_
+    },
+    'ts' = {
+      do.call(stats::ts, append(list(data = df_$value), ts_options))
+    }
+  )
 
-  df_
+  # if (as == 'tibble') {
+  #   df_ <- tibble::as_tibble(df_)
+  #   names(df_) <- c('date', name_)
+  # } else if (as == 'data.frame') {
+  #   names(df_) <- c('date', name_)
+  # } else if (as == 'xts') {
+  #   df_ <- xts::xts(df_$value, df_$date)
+  #   names(df_) <- name_
+  # } else if (as == 'ts') {
+  #   df_ <- do.call(stats::ts, append(list(data = df_$value), ts_options))
+  # }
+  #
+  #   df_
 }
